<?php
/**
 * Template functions
 *
 * Package Manduca
 *
 * @since 17.7
 * */

/*
* Get custom header's alt data.
* 
*/
function manduca_get_header_image_alt() {
    $attachment_id = 0;
    
    if ( is_random_header_image() && $header_url = get_header_image() ) {
	    // For a random header, we have to search for a match against all headers.
	    foreach ( get_uploaded_header_images() as $header ) {
		    if ( $header['url'] == $header_url ) {
			    $attachment_id = $header['attachment_id'];
			    break;
		    }
	    }
    
    } elseif ( $data = get_custom_header() ) {
	    // For static headers, less intensive approach.
	    $attachment_id = $data->attachment_id;
    } 
    
    if ( $attachment_id ) {
	    $alt = trim( strip_tags( get_post_meta( $attachment_id, '_wp_attachment_image_alt', true ) ) );

	    if ( ! $alt ) {
		    $alt = trim( strip_tags( get_post_field( 'post_excerpt', $attachment_id ) ) );
	    }
	    if ( ! $alt ) {
		    $alt = trim( strip_tags( get_post_field( 'post_title', $attachment_id ) ) );
	    }
    }
	else {
	    $alt = '';
    }
    
    return $alt;
}


/*
 * Set body cloasses
 *
 * @since 1.0
 * */

function manduca_body_class( $classes ) {
	$background_color = get_background_color();
	$background_image = get_background_image();

	if ( ! is_active_sidebar( 'main_sidebar' ) || is_page_template( 'page-templates/full-width.php' ) ) {
		$classes[] = 'full-width';
	}

	if ( empty( $background_image ) ) {
		if ( empty( $background_color ) ) {
			$classes[] = 'custom-background-empty';
		}
		elseif ( in_array( $background_color, array( 'fff', 'ffffff' ) ) ) {
			$classes[] = 'custom-background-white';
		}
	}

	if ( ! is_multi_author() ) {
		$classes[] = 'single-author';
	}

	return $classes; 
}
add_filter( 'body_class', 'manduca_body_class' );

 
 
 
  
//-------------------------------------------------------------------------------------------
// Avatar need alt tag
//-------------------------------------------------------------------------------------------

    
function manduca_add_alt_to_avatar( $text )
{
	$alt = get_the_author_meta( 'display_name' );
	$text = str_replace( 'alt=""', 'alt="'.$alt . __( 'avatar', 'manduca' ) , $text );
	return $text;
}
add_filter( 'get_avatar', 'manduca_add_alt_to_avatar' );

/*
 *Manduce unique anchor to "continue reading" button in excerpt
 *
 *
 **/


function manduca_more_unique_id () {
	$title = get_the_title();
	$firstwords = '';
	$space_count = 0;
	
	if ( get_locale() ==='hu_HU' ) {
		$firstwords ='a ';
		$hungarian_regex = '/^[aáeéiíoóöőuúüű]/i';
		if (preg_match ( $hungarian_regex, $title ) ) {
			$firstwords = 'az ';	
		}
	}
	for ( $char_count = 0 ; $char_count < strlen( $title ) ; $char_count++ ) {
		if ( $title{ $char_count } === ' ' ) {
			$space_count++;	
		}
		if( $space_count < 5 ) {
			$firstwords .= $title{ $char_count };
		}
	}
	if ( $space_count > 4) {
		$firstwords .= '&hellip;'; 
	}
	return  sprintf( __( 'Title of article: %s', 'manduca' ), $firstwords );
}

if( !function_exists( 'manduca_content_more_link' ) ) :
	function manduca_content_more_link() {
		$svg = manduca_get_svg( array( 'icon' => 'angle-right' ) ) ;
		$content_more_link = sprintf( '<a href="%1$s" class="more-link color-2" id="continue-reading-%2$s" aria-labelledby="continue-reading-%2$s post-title-%2$s" >%3$s %4$s</a>',
									get_permalink(),
									get_the_ID(),
									__( 'Continue reading', 'manduca' ),
									$svg
								   );
		return $content_more_link;
	}
endif;
	
/*
 *Display continue reading link
 **/

function manduca_the_content_more_link() {
	echo manduca_content_more_link();
}

add_filter( 'the_content_more_link', 'manduca_content_more_link' );
add_filter( 'excerpt_more', 'manduca_content_more_link' );


/*
 * add read-more link to manual excerpt
 * */
function manduca_manual_excerpt ( $excerpt ) {
	global $post;
	if( $post->post_excerpt ) {
		return $excerpt .manduca_content_more_link();
	} else {
		return $excerpt;
	}
}

add_filter('get_the_excerpt', 'manduca_manual_excerpt');

/*
* Add class="ext-link" to external links
*
* */


function manduca_get_domain_name_from_uri( $uri ) {
	preg_match( '/^(http:\/\/)?([^\/]+)/i', $uri, $matches );
	$host = $matches[2];
	preg_match( '/[^\.\/]+\.[^\.\/]+$/', $host, $matches );
	return $host;
}

/* callback function of preg_replace to parse external links
 *
 * @param $matches HTML code to filter
 *
 * @return modified HTML code, where class="wxt-links" are added. 
 *
 * */

function mandcua_parse_external_links( $matches ) {
	if ( manduca_get_domain_name_from_uri( $matches[3] ) != manduca_get_domain_name_from_uri( $_SERVER["HTTP_HOST"] ) &&  $matches[2][0] !=='#') {
		
		$flag = FALSE ;
		foreach( $matches as $key => $match ) {
			
			if( !empty ($match) ) {
				
				if ( strpos( $match, 'class=') !== FALSE  ) {
					$matches[$key] = str_replace ( 'class="', 'class="ext-link ', $match);
					$flag = TRUE;
				}
			}
		}
		
		if ( $flag ) {
		$pattern = '<a href="' . $matches[2] . '//' . $matches[3] . '"' . $matches[1] . $matches[4] .'>' . $matches[5] . '<span class="screen-reader-text"> (' .__( 'external', 'manduca' ) .')</span><svg class="ext-link-svg" viewBox="0 0 1792 1792" xmlns="http://www.w3.org/2000/svg"><path d="M1408 928v320q0 119-84.5 203.5t-203.5 84.5h-832q-119 0-203.5-84.5t-84.5-203.5v-832q0-119 84.5-203.5t203.5-84.5h704q14 0 23 9t9 23v64q0 14-9 23t-23 9h-704q-66 0-113 47t-47 113v832q0 66 47 113t113 47h832q66 0 113-47t47-113v-320q0-14 9-23t23-9h64q14 0 23 9t9 23zm384-864v512q0 26-19 45t-45 19-45-19l-176-176-652 652q-10 10-23 10t-23-10l-114-114q-10-10-10-23t10-23l652-652-176-176q-19-19-19-45t19-45 45-19h512q26 0 45 19t19 45z"/></svg></a>';	 	
		}
		else {
			$pattern = '<a href="' . $matches[2] . '//' . $matches[3] . '"' . $matches[1] . $matches[4] .' class="ext-link">' . $matches[5] . '<span class="screen-reader-text"> (' .__( 'external', 'manduca' ) .')</span><svg class="ext-link-svg" viewBox="0 0 1792 1792" xmlns="http://www.w3.org/2000/svg"><path d="M1408 928v320q0 119-84.5 203.5t-203.5 84.5h-832q-119 0-203.5-84.5t-84.5-203.5v-832q0-119 84.5-203.5t203.5-84.5h704q14 0 23 9t9 23v64q0 14-9 23t-23 9h-704q-66 0-113 47t-47 113v832q0 66 47 113t113 47h832q66 0 113-47t47-113v-320q0-14 9-23t23-9h64q14 0 23 9t9 23zm384-864v512q0 26-19 45t-45 19-45-19l-176-176-652 652q-10 10-23 10t-23-10l-114-114q-10-10-10-23t10-23l652-652-176-176q-19-19-19-45t19-45 45-19h512q26 0 45 19t19 45z"/></svg></a>';	 
		}
		return $pattern;
	
	} else {
		return '<a href="' . $matches[2] . '//' . $matches[3] . '"' . $matches[1] . $matches[4] . '>' . $matches[5] . '</a>';
	}
}
	

function manduca_external_links( $text ) {
	$pattern = '/<a (.*?)href="(.*?)\/\/(.*?)"(.*?)>(.*?)<\/a>/i';
	$text = preg_replace_callback( $pattern, 'mandcua_parse_external_links', $text );
	return $text;
}

// filters have high priority to make sure that any markup plugins like Textile or Markdown have already created the HTML links
add_filter( 'the_content', 'manduca_external_links', 999 );
add_filter( 'the_excerpt', 'manduca_external_links', 999 );

// delete this one if you don't want it run on comments
add_filter( 'comment_text', 'manduca_external_links', 999 );

/**
 * Change HTML headings
 * 
 * */

if( !function_exists( 'manduca_heading_correction' ) ) :

	function manduca_heading_correction ( $content ) {
		if ( is_archive() ) {
			$content = str_replace( '<h4>', '<h5>', $content );
			$content = str_replace( '</h4>', '</h5>', $content );
			$content = str_replace( '<h3>', '<h4>', $content );
			$content = str_replace( '</h3>', '</h4>', $content );
			$content = str_replace( '<h2>', '<h3>', $content );
			$content = str_replace( '</h2>', '</h3>', $content );
		}
		return $content;
	}

	add_filter( 'the_content', 'manduca_heading_correction' );

endif;


 
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @since 17.7.
 */

if ( ! function_exists( 'manduca_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function manduca_posted_on() {

	// Get the author name; wrap it in a link.
	$byline = sprintf(
		/* translators: %s: post author */
		__( 'by %s', 'manduca' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . get_the_author() . '</a></span>'
	);

	// Finally, let's write all of this to the page.
	echo '<span class="posted-on">' . manduca_time_link() . '</span><span class="byline"> ' . $byline . '</span>';
}
endif;


if ( ! function_exists( 'manduca_time_link' ) ) :
/**
 * Gets a nicely formatted string for the published date.
 */
function manduca_time_link() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		get_the_date( DATE_W3C ),
		get_the_date(),
		get_the_modified_date( DATE_W3C ),
		get_the_modified_date()
	);

	// Wrap the time string in a link, and preface it with 'Posted on'.
	return sprintf(
		/* translators: %s: post date */
		__( '<span class="screen-reader-text">Posted on</span> %s', 'manduca' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);
}
endif;


/*
 *Displays entry meta data
 **/

if ( ! function_exists( 'manduca_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function manduca_entry_footer() {

	/* translators: used between list items, there is a space after the comma */
	$separate_meta = __( ', ', 'manduca' );

	// Get Categories for posts.
	$categories_list = get_the_category_list( $separate_meta );

	// Get Tags for posts.
	$tags_list = get_the_tag_list( '', $separate_meta );

	// We don't want to output .entry-footer if it will be empty, so make sure its not.
	if ( ( ( manduca_categorized_blog() && $categories_list ) || $tags_list ) || get_edit_post_link() ) {

		echo '<footer class="entry-footer">';

			if ( 'post' === get_post_type() ) {
				if ( ( $categories_list && manduca_categorized_blog() ) || $tags_list ) {
					echo '<span class="cat-tags-links">';

						// Make sure there's more than one category before displaying.
						if ( $categories_list && manduca_categorized_blog() ) {
							echo '<span class="cat-links">' . manduca_get_svg( array( 'icon' => 'folder-open' ) ) . '<span class="screen-reader-text">' . __( 'Categories', 'manduca' ) . '</span>' . $categories_list . '</span>';
						}

						if ( $tags_list ) {
							echo '<span class="tags-links">' . manduca_get_svg( array( 'icon' => 'hashtag' ) ) . '<span class="screen-reader-text">' . __( 'Tags', 'manduca' ) . '</span>' . $tags_list . '</span>';
						}

					echo '</span>';
				}
			}

			manduca_edit_post_link();

		echo '</footer> <!-- .entry-footer -->';
	}
}
endif;


if ( ! function_exists( 'manduca_edit_post_link' ) ) :
/**
 * Displays an accessibility-friendly link to edit a post or page.
 *
 * This also gives us a little context about what exactly we're editing
 * (post or page?) so that users understand a bit more where they are in terms
 * of the template hierarchy and their content. Helpful when/if the single-page
 * layout with multiple posts/pages shown gets confusing.
 *
 * @since 17.9
 */
function manduca_edit_post_link() {
	$svg= manduca_get_svg ( array( 'icon' => 'pencil' ) );
	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			__( 'Edit', 'manduca' ) .'<span class="screen-reader-text"> "%s"</span>',
			get_the_title()
		),
		'<span class="edit-link">' .$svg,
		'</span>'
	);
}
endif;



/*
 *Add anchor to image anchor insert in post content
 *
 *@since 16.10
 *
 */


function manduca_add_class_image_anchor($html, $id, $caption, $title, $align, $url, $size, $alt = '' ){
  $classes = 'image-link'; 

  if ( preg_match('/<a.*? class=".*?">/', $html) ) {
    $html = preg_replace('/(<a.*? class=".*?)(".*?>)/', '$1 ' . $classes . '$2', $html);
  } else {
    $html = preg_replace('/(<a.*?)>/', '$1 class="' . $classes . '" >', $html);
  }
  return $html;
}
add_filter('image_send_to_editor','manduca_add_class_image_anchor',10,8);

/*
 * Modify WordPress classes of article
 *
 * Remove all classes
 * Add color-1 class to sticky posts
 *
 * @since 17.9
 * */
function manduca_article_classes( $classes ) {
	
	
	
	$classes = array(
		'post'
	);
	
	//Sticky post has different color
	if (is_sticky() ) {
		$classes[] = 'color-1';
		$classes[] = 'sticky';
	}
	return $classes;
}

add_filter( 'post_class' , 'manduca_article_classes' );

 
/*
 *Display excerpt with navigation bar
 *
 * @since 17.1
 **/
if( !function_exists( 'manduca_display_excerpt' ) ) :
 
	function manduca_display_excerpt() {

		$nav = manduca_get_post_pagination();
			
		echo $nav;
		
		get_template_part( 'template-parts/content', 'excerpt' );
		
		echo $nav;

	}
endif;



?>