<?php
/**
 * Manduca
 *
 * @since 17.7 */

if ( ! isset( $content_width ) ) {
	$content_width = 625;
}

//-------------------------------------------------------------------------------------------
// Manduca setup
//-------------------------------------------------------------------------------------------
function manduca_setup() {
	
	// Styles the visual editor with editor-style.css
	add_editor_style();
	
	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );
	
	// Switch default core markup to output valid HTML5.
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'caption', 'gallery'
	) );
	//Allows themes to add document title tag
	add_theme_support( 'title-tag' );
	
	//Register navigation menus
	register_nav_menu( 'primary', __( 'Main navigation', 'manduca' ) );
	register_nav_menu( 'footer', __( 'Footer navigation', 'manduca' ) );
	
	//Makes translation-ready
	load_theme_textdomain( 'manduca', get_template_directory() . '/assets/lang' );
	
	
	 //Supports custom background color and image
	add_theme_support( 'custom-background', array(
		'default-color' => 'f3f3f5',
	) );
	

	// Uses a custom image size for featured images
	add_theme_support( 'post-thumbnails' );
	add_image_size ('post-size', 890, 592 );
	add_image_size ('excerpt-size', 268, 178 );
}
add_action( 'after_setup_theme', 'manduca_setup' );

require( get_template_directory() . '/inc/custom-header.php' );


 


/**
 *Image optimazation
 *delete WordPress default image sizes
 *
 **/
function manduca_filter_image_sizes( $sizes) {
	unset( $sizes[ 'medium' ] );
	unset( $sizes[ 'large' ] );
 
	return $sizes;
}

add_filter('intermediate_image_sizes_advanced', 'manduca_filter_image_sizes');
 
function manduca_custom_image_sizes($sizes) {
	$add_sizes = array(
		'thumbnail-size' 	=> __( 'Thumbnail', 'manduca' ),
		'post-size' 		=> __( 'Image in Post', 'manduca' ),
		'full' 				=> __( 'Original size', 'manduca' )
	);
	$new_sizes = array_merge($sizes, $add_sizes);
	return $new_sizes;
}
add_filter('image_size_names_choose', 'manduca_custom_image_sizes');

 
 
/*
* Manduca styles and scripts
*
* &since 1.0
*/

function manduca_scripts_styles() {
	global $wp_styles;


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Loads stylesheets.
	wp_enqueue_style( 'manduca-main-style', get_stylesheet_uri(), false, false, 'all' );
	
	//load print stylesheets
	$print_css = get_stylesheet_directory() . '/print.css' ;
	
	if ( is_child_theme() && file_exists( $print_css ) ) { //if child theme has own print.css in its root directory, load it. 
	
			wp_enqueue_style( get_stylesheet().'-print-style', get_stylesheet_directory_uri() .'/print.css' , false, false, 'print'  );	
	
	}
	
	else {
		wp_enqueue_style( 'manduca-print-style', get_template_directory_uri() .'/assets/css/print.css', array() , false, 'print'  );	
	}
		
	// Loads the Internet Explorer specific stylesheet.
	wp_enqueue_style( 'manduca-ie', get_template_directory_uri() . '/assets/css/ie.css', array( 'manduca-style' ) );
	$wp_styles->add_data( 'manduca-ie', 'conditional', 'lt IE 9' );
	
	wp_enqueue_script( 'manduca-scripts', get_template_directory_uri() . '/assets/js/manduca-scripts.js', array( 'jquery' ), '', 'true'); 
	
			
		$manduca_l10n['expand']         = __( 'expand child menu', 'manduca' );
		$manduca_l10n['collapse']       = __( 'collapse child menu', 'manduca' );
		$manduca_l10n['icon']           = manduca_get_svg( array( 'icon' => 'caret-down', 'fallback' => true ) );
		wp_localize_script( 'manduca-scripts', 'manducaScreenReaderText', $manduca_l10n );

		
		/*
		 *Set the color of focus snail
		 *
		 *@since 17.9
		 **/
		$focus_snail[ 'red']  = 158;
		$focus_snail[ 'green']  = 67;
		$focus_snail[ 'blue']  = 14;
		
		/*
		 *allow to change the colour of focus snail
		 *
		 **/
		$focus_snail = apply_filters( 'manduca_focus_snail_color' ,  $focus_snail );
		
		wp_localize_script( 'manduca-scripts', 'manducaFocusSnailColour', $focus_snail );
}

add_action( 'wp_enqueue_scripts', 'manduca_scripts_styles' );



/**
 * Load Enqueued Scripts in the Footer
 * Automatically move JavaScript code to page footer, speeding up page loading time.
 * 
 * @since 17.7
 **/
  
function manduca_move_scripts_to_footer() {
   remove_action('wp_head', 'wp_enqueue_scripts', 1);
   add_action('wp_footer', 'wp_enqueue_scripts', 5);
}
add_action('after_setup_theme', 'manduca_move_scripts_to_footer' );


/*
 * register Manduca's sidebar
 *
 * @ since 1.0
 **/
		
function manduca_widgets_init() {
		register_sidebar( array(
			'name' =>__( 'Sidebar', 'manduca' ),
			'id' => 'main_sidebar',
			'description' => __( 'Appears all pages except when using full page template', 'manduca' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget' => '</div></section>',
			'before_title' => '<h1 class="widget-title">',
			'after_title' =>'</h1><div class="widget-content">',
		) );
}
add_action( 'widgets_init', 'manduca_widgets_init' );



/*
 * Stop reserving slug for media items.
 * Computes a unique slug for the post, when given the desired slug and some post details.
 *
 * @since 16.7
 *
 **/

add_filter( 'wp_unique_post_slug_is_bad_attachment_slug', '__return_true' );



/*
 * Remove gallery inline style
 *
 * @since 17.1
 * */
add_filter( 'use_default_gallery_style', '__return_false' );
 
?>